summaryrefslogtreecommitdiff
path: root/src/lib/ffmpeg_content.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/ffmpeg_content.h')
-rw-r--r--src/lib/ffmpeg_content.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/lib/ffmpeg_content.h b/src/lib/ffmpeg_content.h
index b1f2abcea..d1aa3a0b5 100644
--- a/src/lib/ffmpeg_content.h
+++ b/src/lib/ffmpeg_content.h
@@ -46,9 +46,10 @@ public:
void as_xml (xmlpp::Node *) const;
/** @param c An AVFormatContext.
* @return Stream index within the AVFormatContext.
*/
- int index (AVFormatContext const * c) const;
+ bool uses_index (AVFormatContext const * c, int index) const;
AVStream* stream (AVFormatContext const * c) const;
std::string name;
@@ -46,9 +46,10 @@ public:
void as_xml (xmlpp::Node *) const;
/** @param c An AVFormatContext.
- * @return Stream index within the AVFormatContext.
+ * @param index A stream index within the AVFormatContext.
+ * @return true if this FFmpegStream uses the given stream index.
*/